import {inject, singleton} from 'tsyringe'
import {v4} from 'uuid'
import { models } from '@tonality/library-common'
import {RingtoneRepository} from './repository'
import {DoubleDeletionError} from './response'

@singleton()
export class RingtoneService {
	constructor(
		@inject('RingtoneRepository')
		private readonly ringtoneRepository: RingtoneRepository
	) {
	}

	async get(id: string): Promise<models.Ringtone> {
		return this.ringtoneRepository.get(id)
	}

	async browse(skip: number = 0, take: number = 10): Promise<models.Ringtone[]> {
		return this.ringtoneRepository.browse(skip, take)
	}

	async search(q: string = ''): Promise<models.Ringtone[]> {
		return this.ringtoneRepository.search(q)
	}

	async create(data: Partial<models.Ringtone>): Promise<models.Ringtone> {
		const { createdAt, updatedAt, deletedAt, ...safeData } = data
		const now = new Date()
		const newId = v4()
		return this.ringtoneRepository.create({
			...safeData,
			id: newId,
			createdAt: now,
			updatedAt: now,
		})
	}

	async update(data: Partial<models.Ringtone>): Promise<models.Ringtone> {
		const { createdAt, updatedAt, deletedAt, ...safeData } = data
		return this.ringtoneRepository.update({
			...safeData,
			updatedAt: new Date(),
		})
	}

	async softDelete(id: string): Promise<models.Ringtone> {
		return this.ringtoneRepository.softDelete(id, new Date())
	}

	async undoDelete(id: string): Promise<models.Ringtone> {
		return this.ringtoneRepository.undoDelete(id)
	}

	async hardDelete(id: string): Promise<void> {
		const deleted = await this.ringtoneRepository.hardDelete(id)
		if (!deleted) {
			throw new DoubleDeletionError('Attempt to delete non-existing ringtone.')
		}
	}
}
