import {Knex, knex} from 'knex'

export type QueryBuilder = Knex

export type DatabaseOptions = {
	engine: unknown,
	type: string,
	location: string,
	username?: string,
	password?: string,
	schema?: string,
	version?: string,
}

const normalTypes: Record<string, string> = {
	postgres: 'pg',
	pg: 'pg',
	postgresql: 'pg',
	mysql: 'mysql',
	mariadb: 'mysql',
	sqlite: 'sqlite3',
	sqlite3: 'sqlite3',
}

export const createQueryBuilder = ({
	type,
	engine,
	location,
	...etcOptions
}: DatabaseOptions) => {
	const { [type]: theType = null } = normalTypes

	if (theType === null) {
		throw new RangeError(`Invalid type: ${type}`)
	}

	switch (theType as string) {
	case 'sqlite3':
		return knex({
			client: theType,
			connection: {
				filename: location,
			}
		})
	default:
		break
	}

	const { username, password, schema, version, } = etcOptions
	return knex({
		client: theType,
		version,
		connection: {
			host: location,
			user: username,
			password,
			database: schema,
		},
	})
}

export class Database {
	private readonly queryBuilder: QueryBuilder

	constructor({
		type,
		engine,
		location,
		...etcOptions
	}: DatabaseOptions) {
		const { [type]: theType = null } = normalTypes

		if (theType === null) {
			throw new RangeError(`Invalid type: ${type}`)
		}

		switch (theType as string) {
		case 'sqlite3':
			this.queryBuilder = knex({
				client: theType,
				connection: {
					filename: location,
				}
			})
			return
		default:
			break
		}

		const { username, password, schema, version, } = etcOptions
		this.queryBuilder = knex({
			client: theType,
			version,
			connection: {
				host: location,
				user: username,
				password,
				database: schema,
			},
		})
	}

	async run(cb: (qb: QueryBuilder) => any) {
		const rawQuery = cb(this.queryBuilder)
		if (!rawQuery) {
			throw new Error('Invalid callback.')
		}

		return rawQuery
	}
}
